@@ -1,3 +1,5 @@
+from collections import defaultdict
+
 from prettytable import PrettyTable
 
 
@@ -12,7 +14,7 @@ def init_pretty_table():
 class QuarkAnalysis:
     __slots__ = ["crime_description", "first_api", "second_api", "level_1_result", "level_2_result", "level_3_result",
                  "level_4_result", "level_5_result", "json_report", "weight_sum", "score_sum", "summary_report_table",
-                 "call_graph_analysis_list"]
+                 "call_graph_analysis_list", "parent_wrapper_mapping"]
 
     def __init__(self):
         self.crime_description = ""
@@ -34,6 +36,9 @@ class QuarkAnalysis:
         # Call graph analysis
         self.call_graph_analysis_list = []
 
+        # Mapping between the parent function and the wrapper method
+        self.parent_wrapper_mapping = defaultdict(str)
+
     def clean_result(self):
         self.level_1_result.clear()
         self.level_2_result.clear()
