@@ -136,6 +136,12 @@ class Quark:
                 if tools.contains(sequence_pattern_method, method_list_need_check):
                     state = True
 
+                    # Record the mapping between the parent function and the wrapper method
+                    self.quark_analysis.parent_wrapper_mapping[
+                        mutual_parent.full_name] = self.apkinfo.get_wrapper_smali(mutual_parent,
+                                                                                  first_call_method,
+                                                                                  second_call_method)
+
         return state
 
     def check_parameter(self, parent_function, first_method_list, second_method_list):
@@ -180,6 +186,13 @@ class Quark:
                             if first_method_pattern in c_func and second_method_pattern in c_func:
                                 state = True
 
+                                # Record the mapping between the parent function and the wrapper method
+                                self.quark_analysis.parent_wrapper_mapping[
+                                    parent_function.full_name] = self.apkinfo.get_wrapper_smali(
+                                    parent_function,
+                                    first_call_method,
+                                    second_call_method)
+
                 # Build for the call graph
                 if state:
                     call_graph_analysis = {"parent": parent_function,
@@ -341,16 +354,14 @@ class Quark:
         if self.quark_analysis.level_4_result and rule_obj.check_item[3]:
             for item4 in self.quark_analysis.level_4_result:
                 sequnce_show_up.append({
-                    "class": repr(item4.class_name),
-                    "method": repr(item4.name),
+                    repr(item4.full_name): self.quark_analysis.parent_wrapper_mapping[item4.full_name]
                 })
 
             # Check examination has passed level 5
             if self.quark_analysis.level_5_result and rule_obj.check_item[4]:
                 for item5 in self.quark_analysis.level_5_result:
                     same_operation_show_up.append({
-                        "class": repr(item5.class_name),
-                        "method": repr(item5.name),
+                        repr(item5.full_name): self.quark_analysis.parent_wrapper_mapping[item5.full_name]
                     })
 
         crime = {
@@ -371,7 +382,21 @@ class Quark:
         # add the score
         self.quark_analysis.score_sum += score
 
-    def show_summary_report(self, rule_obj):
+    def add_table_row(self, rule_obj, confidence, score, weight):
+
+        self.quark_analysis.summary_report_table.add_row([
+            green(rule_obj.crime),
+            yellow(confidence),
+            score,
+            red(weight),
+        ])
+
+        # add the weight
+        self.quark_analysis.weight_sum += weight
+        # add the score
+        self.quark_analysis.score_sum += score
+
+    def show_summary_report(self, rule_obj, threshold=None):
         """
         Show the summary report.
 
@@ -379,21 +404,18 @@ class Quark:
         :return: None
         """
         # Count the confidence
-        confidence = str(rule_obj.check_item.count(True) * 20) + "%"
+        confidence = f"{rule_obj.check_item.count(True) * 20}%"
         conf = rule_obj.check_item.count(True)
         weight = rule_obj.get_score(conf)
         score = rule_obj.yscore
 
-        self.quark_analysis.summary_report_table.add_row([
-            green(rule_obj.crime), yellow(
-                confidence,
-            ), score, red(weight),
-        ])
+        if threshold:
 
-        # add the weight
-        self.quark_analysis.weight_sum += weight
-        # add the score
-        self.quark_analysis.score_sum += score
+            if rule_obj.check_item.count(True) * 20 >= int(threshold):
+                self.add_table_row(rule_obj, confidence, score, weight)
+
+        else:
+            self.add_table_row(rule_obj, confidence, score, weight)
 
     def show_detail_report(self, rule_obj):
         """
