@@ -6,14 +6,16 @@ from tqdm import tqdm
 
 from quark.Objects.quark import Quark
 from quark.Objects.quarkrule import QuarkRule
+from quark.freshquark import check_update
 from quark.logo import logo
 from quark.utils.out import print_success, print_info, print_warning
 from quark.utils.weight import Weight
 
 logo()
+check_update()
 
 
-@click.command()
+@click.command(no_args_is_help=True)
 @click.option("-s", "--summary", is_flag=True, help="Show summary report")
 @click.option("-d", "--detail", is_flag=True, help="Show detail report")
 @click.option(
@@ -51,7 +53,14 @@ logo()
     help="Show rules classification",
     required=False,
 )
-def entry_point(summary, detail, apk, rule, output, graph, classification):
+@click.option(
+    "-t",
+    "--threshold",
+    help="Set the confidence threshold",
+    type=click.Choice(["100", "80", "60", "40", "20"]),
+    required=False,
+)
+def entry_point(summary, detail, apk, rule, output, graph, classification, threshold):
     """Quark is an Obfuscation-Neglect Android Malware Scoring System"""
 
     if summary:
@@ -70,7 +79,7 @@ def entry_point(summary, detail, apk, rule, output, graph, classification):
                 # Run the checker
                 data.run(rule_checker)
 
-                data.show_summary_report(rule_checker)
+                data.show_summary_report(rule_checker, threshold)
 
         w = Weight(data.quark_analysis.score_sum, data.quark_analysis.weight_sum)
         print_warning(w.calculate())
