@@ -1,3 +1,5 @@
+from quark import __version__
+
 from quark.utils.colors import bold, lightyellow, lightblue
 
 
@@ -7,19 +9,19 @@ def logo():
             lightyellow(
                 """
     ________                      __
-    \_____  \  __ _______ _______|  | __
-     /  / \  \|  |  \__  \\_  __ \  |/ /
-    /   \_/.  \  |  // __ \|  | \/    <
-    \_____\ \_/____/(____  /__|  |__|_ \\
-           \__>          \/           \/ v{}
+    \\_____  \\  __ _______ _______|  | __
+     /  / \\  \\|  |  \\__  \\_  __ \\  |/ /
+    /   \\_/.  \\  |  // __ \\|  | \\/    <
+    \\_____\\ \\_/____/(____  /__|  |__|_ \\
+           \\__>          \\/           \\/ v{}
     """
-            )
-        ).format("20.01")
+            ),
+        ).format(__version__)
         + bold(
             lightblue(
                 """
             An Obfuscation-Neglect Android Malware Scoring System
             """
-            )
-        )
+            ),
+        ),
     )
